==> libgtop-2.9.0.tar.bz2: libgtop-2.9.0/sysdeps/linux/uptime.c <==
/* $Id: uptime.c,v 1.22 2004/11/28 01:32:55 bdejean Exp $ */

/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <config.h>
#include <glibtop/error.h>
#include <glibtop/uptime.h>

#include "glibtop_private.h"

#include <time.h>

static const unsigned long _glibtop_sysdeps_uptime =
(1L << GLIBTOP_UPTIME_UPTIME) + (1L << GLIBTOP_UPTIME_IDLETIME);

/* Init function. */

void
glibtop_init_uptime_s (glibtop *server)
{
	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
}

/* Provides uptime and idle time. */

#define FILENAME	"/proc/uptime"

void
glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
{
	char buffer [BUFSIZ], *p;

	glibtop_init_s (&server, GLIBTOP_SYSDEPS_UPTIME, 0);

	memset (buf, 0, sizeof (glibtop_uptime));

	file_to_buffer(server, buffer, FILENAME);

	buf->uptime   = strtod (buffer, &p);
	buf->idletime = strtod (p, &p);
	buf->boot_time = (guint64) time(NULL) - (guint64) buf->uptime;

	buf->flags = _glibtop_sysdeps_uptime;
}

==> libgtop-2.10.2.tar.bz2: libgtop-2.10.2/sysdeps/linux/uptime.c <==
/* $Id: uptime.c,v 1.23 2005/03/27 14:30:30 bdejean Exp $ */

/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <config.h>
#include <glibtop/error.h>
#include <glibtop/uptime.h>

#include "glibtop_private.h"

#include <time.h>

static const unsigned long _glibtop_sysdeps_uptime =
(1L << GLIBTOP_UPTIME_UPTIME) + (1L << GLIBTOP_UPTIME_IDLETIME);

/* Init function. */

void
glibtop_init_uptime_s (glibtop *server)
{
	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
}

/* Provides uptime and idle time. */

#define FILENAME	"/proc/uptime"

void
glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
{
	char buffer [BUFSIZ], *p;

	glibtop_init_s (&server, GLIBTOP_SYSDEPS_UPTIME, 0);

	memset (buf, 0, sizeof (glibtop_uptime));

	file_to_buffer(server, buffer, FILENAME);

	buf->uptime   = g_ascii_strtod (buffer, &p);
	buf->idletime = g_ascii_strtod (p, &p);
	buf->boot_time = (guint64) time(NULL) - (guint64) buf->uptime;

	buf->flags = _glibtop_sysdeps_uptime;
}
